[project]
name = "django-PPM_salah_dev"
version = "0.0.1 Alpha"
authors = [
  { name="Salah Aldain Alhajj", email="contact@salahaldain.com" },
]
description = "Private Package Manager Python Packages"
readme = "README.md"
requires-python = ">=3.8"
classifiers = [
    "Programming Language :: Python :: 3",
    "License :: OSI Approved :: MIT License",
    "Operating System :: OS Independent",
]

[project.urls]
Homepage = "https://github.com/salah-alhajj/django-PPM.git"
Issues = "https://github.com/salah-alhajj/django-PPM/issues"
